==> jc-1.4.0.tar.gz: java/awt/AttributeValue.c <==
// class java.awt.AttributeValue

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String

// header file dependencies
// @dep_header java_awt_AttributeValue
// @dep_header java_lang_Class
// @dep_header java_lang_String

#include "jc_defs.h"

#include "java/awt/AttributeValue.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// final int value
static _jc_field _jc_java_awt_AttributeValue$field_info$value = {
	.name=		"value",
	.signature=	"I",
	.class=		&_jc_java_awt_AttributeValue$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_java_awt_AttributeValue$object, nonrefs.java_awt_AttributeValue.value),
};

// private final java.lang.String[] names
static _jc_field _jc_java_awt_AttributeValue$field_info$names = {
	.name=		"names",
	.signature=	"[Ljava/lang/String;",
	.class=		&_jc_java_awt_AttributeValue$type,
	.type=		&_jc_java_lang_String$array$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_java_awt_AttributeValue$object, refs[-1].java_awt_AttributeValue.names),
};

// Fields
static _jc_field *const _jc_java_awt_AttributeValue$fields[] = {
	&_jc_java_awt_AttributeValue$field_info$names,
	&_jc_java_awt_AttributeValue$field_info$value
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(int, java.lang.String[])
//

static _jc_linenum _jc_java_awt_AttributeValue$linenum_table$_init$8ea9c163215ed755[];

static const unsigned char _jc_java_awt_AttributeValue$param_ptypes$_init$8ea9c163215ed755[] = { 
_JC_TYPE_INT, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_awt_AttributeValue$param_types$_init$8ea9c163215ed755[] = {
	&_jc_int$prim$type,
	&_jc_java_lang_String$array$type
};

_jc_method _jc_java_awt_AttributeValue$method_info$_init$8ea9c163215ed755 = {
	.name=			"<init>",
	.signature=		"(I[Ljava/lang/String;)V",
	.class=			&_jc_java_awt_AttributeValue$type,
	.param_types=		&_jc_java_awt_AttributeValue$param_types$_init$8ea9c163215ed755,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_awt_AttributeValue$param_ptypes$_init$8ea9c163215ed755,
	.signature_hash=	_JC_JLONG(0x8ea9c163215ed755),
	.access_flags=		0,
	.function=		&_jc_java_awt_AttributeValue$method$_init$8ea9c163215ed755,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_java_awt_AttributeValue$linenum_table$_init$8ea9c163215ed755
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_AttributeValue, _init$8ea9c163215ed755);

void
_jc_java_awt_AttributeValue$method$_init$8ea9c163215ed755(_jc_env *const env, _jc_java_awt_AttributeValue$object *this, jint param0, _jc_object_array *param1)
{
	jint i0;
	struct _jc_java_awt_AttributeValue$object *r0;
	_jc_object_array *r1;

	r0 = this;
	i0 = param0;
	r1 = param1;
	_JC_LINE_NUMBER(74);				// 0
	_JC_PRIM_FIELD(env, r0, java_awt_AttributeValue, value) = i0;
	_JC_LINE_NUMBER(75);				// 1
	_JC_REF_FIELD(env, r0, java_awt_AttributeValue, names) = r1;
	_JC_LINE_NUMBER(76);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public int hashCode()
//

static _jc_linenum _jc_java_awt_AttributeValue$linenum_table$hashCode$53152098849316df[];

static const unsigned char _jc_java_awt_AttributeValue$param_ptypes$hashCode$53152098849316df[] = { 
_JC_TYPE_INT };

_jc_method _jc_java_awt_AttributeValue$method_info$hashCode$53152098849316df = {
	.name=			"hashCode",
	.signature=		"()I",
	.class=			&_jc_java_awt_AttributeValue$type,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_java_awt_AttributeValue$param_ptypes$hashCode$53152098849316df,
	.signature_hash=	_JC_JLONG(0x53152098849316df),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_awt_AttributeValue$method$hashCode$53152098849316df,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_awt_AttributeValue$vtable, java_awt_AttributeValue.hashCode$53152098849316df) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_awt_AttributeValue$linenum_table$hashCode$53152098849316df
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_AttributeValue, hashCode$53152098849316df);

jint
_jc_java_awt_AttributeValue$method$hashCode$53152098849316df(_jc_env *const env, _jc_java_awt_AttributeValue$object *this)
{
	jint i0;
	struct _jc_java_awt_AttributeValue$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(86);				// 0
	i0 = _JC_PRIM_FIELD(env, r0, java_awt_AttributeValue, value);
	return i0;
}

//
// public java.lang.String toString()
//

static _jc_linenum _jc_java_awt_AttributeValue$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_java_awt_AttributeValue$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_awt_AttributeValue$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_awt_AttributeValue$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_awt_AttributeValue$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_awt_AttributeValue$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_awt_AttributeValue$vtable, java_awt_AttributeValue.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_awt_AttributeValue$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_AttributeValue, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_java_awt_AttributeValue$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_java_awt_AttributeValue$object *this)
{
	jint i0;
	struct _jc_java_awt_AttributeValue$object *r0;
	_jc_object_array *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	_JC_LINE_NUMBER(96);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_awt_AttributeValue, names);
	i0 = _JC_PRIM_FIELD(env, r0, java_awt_AttributeValue, value);
	r2 = _JC_REF_ELEMENT(env, r1, i0, 1, 1);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_awt_AttributeValue$methods[] = {
	&_jc_java_awt_AttributeValue$method_info$_init$8ea9c163215ed755,
	&_jc_java_awt_AttributeValue$method_info$hashCode$53152098849316df,
	&_jc_java_awt_AttributeValue$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_awt_AttributeValue$instanceof_hash_bucket_109[] = {
	&_jc_java_awt_AttributeValue$type,
	_JC_NULL
};
static _jc_type *const _jc_java_awt_AttributeValue$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_awt_AttributeValue$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[109]=	_jc_java_awt_AttributeValue$instanceof_hash_bucket_109,
	[113]=	_jc_java_awt_AttributeValue$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_awt_AttributeValue$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_awt_AttributeValue$vtype _jc_java_awt_AttributeValue$type = {
    .type= {
	.name=			"java/awt/AttributeValue",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xad57b0121b5be9ed),
		.source_file=		"AttributeValue.java",
		.instance_size=		sizeof(_jc_java_awt_AttributeValue$refs) + sizeof(_jc_java_awt_AttributeValue$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_awt_AttributeValue$fields) / sizeof(*_jc_java_awt_AttributeValue$fields),
		.fields=		_jc_java_awt_AttributeValue$fields,
		.num_methods=		sizeof(_jc_java_awt_AttributeValue$methods) / sizeof(*_jc_java_awt_AttributeValue$methods),
		.methods=		_jc_java_awt_AttributeValue$methods,
		.instanceof_hash_table=	_jc_java_awt_AttributeValue$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_awt_AttributeValue$class_depends) / sizeof(*_jc_java_awt_AttributeValue$class_depends),
		.class_depends=		_jc_java_awt_AttributeValue$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=			// overridden
		&_jc_java_awt_AttributeValue$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_awt_AttributeValue$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_awt_AttributeValue= {
	    .hashCode$53152098849316df=
		&_jc_java_awt_AttributeValue$method$hashCode$53152098849316df,
	    .toString$7ea43b33b80a3070=
		&_jc_java_awt_AttributeValue$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: java/awt/AttributeValue.c <==
// class java.awt.AttributeValue

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String

// header file dependencies
// @dep_header java_awt_AttributeValue
// @dep_header java_lang_Class
// @dep_header java_lang_String

#include "jc_defs.h"

#include "java/awt/AttributeValue.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// final int value
static _jc_field _jc_java_awt_AttributeValue$field_info$value = {
	.name=		"value",
	.signature=	"I",
	.class=		&_jc_java_awt_AttributeValue$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_java_awt_AttributeValue$object, nonrefs.java_awt_AttributeValue.value),
};

// private final java.lang.String[] names
static _jc_field _jc_java_awt_AttributeValue$field_info$names = {
	.name=		"names",
	.signature=	"[Ljava/lang/String;",
	.class=		&_jc_java_awt_AttributeValue$type,
	.type=		&_jc_java_lang_String$array$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_java_awt_AttributeValue$object, refs[-1].java_awt_AttributeValue.names),
};

// Fields
static _jc_field *const _jc_java_awt_AttributeValue$fields[] = {
	&_jc_java_awt_AttributeValue$field_info$names,
	&_jc_java_awt_AttributeValue$field_info$value
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(int, java.lang.String[])
//

static _jc_linenum _jc_java_awt_AttributeValue$linenum_table$_init$8ea9c163215ed755[];

static const unsigned char _jc_java_awt_AttributeValue$param_ptypes$_init$8ea9c163215ed755[] = { 
_JC_TYPE_INT, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_awt_AttributeValue$param_types$_init$8ea9c163215ed755[] = {
	&_jc_int$prim$type,
	&_jc_java_lang_String$array$type
};

_jc_method _jc_java_awt_AttributeValue$method_info$_init$8ea9c163215ed755 = {
	.name=			"<init>",
	.signature=		"(I[Ljava/lang/String;)V",
	.class=			&_jc_java_awt_AttributeValue$type,
	.param_types=		&_jc_java_awt_AttributeValue$param_types$_init$8ea9c163215ed755,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_awt_AttributeValue$param_ptypes$_init$8ea9c163215ed755,
	.signature_hash=	_JC_JLONG(0x8ea9c163215ed755),
	.access_flags=		0,
	.function=		&_jc_java_awt_AttributeValue$method$_init$8ea9c163215ed755,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_java_awt_AttributeValue$linenum_table$_init$8ea9c163215ed755
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_AttributeValue, _init$8ea9c163215ed755);

void _JC_JCNI_ATTR
_jc_java_awt_AttributeValue$method$_init$8ea9c163215ed755(_jc_env *const env, _jc_java_awt_AttributeValue$object *this, jint param0, _jc_object_array *param1)
{
	jint i0;
	struct _jc_java_awt_AttributeValue$object *r0;
	_jc_object_array *r1;

	r0 = this;
	i0 = param0;
	r1 = param1;
	_JC_LINE_NUMBER(74);				// 0
	_JC_PRIM_FIELD(env, r0, java_awt_AttributeValue, value) = i0;
	_JC_LINE_NUMBER(75);				// 1
	_JC_REF_FIELD(env, r0, java_awt_AttributeValue, names) = r1;
	_JC_LINE_NUMBER(76);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public int hashCode()
//

static _jc_linenum _jc_java_awt_AttributeValue$linenum_table$hashCode$53152098849316df[];

static const unsigned char _jc_java_awt_AttributeValue$param_ptypes$hashCode$53152098849316df[] = { 
_JC_TYPE_INT };

_jc_method _jc_java_awt_AttributeValue$method_info$hashCode$53152098849316df = {
	.name=			"hashCode",
	.signature=		"()I",
	.class=			&_jc_java_awt_AttributeValue$type,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_java_awt_AttributeValue$param_ptypes$hashCode$53152098849316df,
	.signature_hash=	_JC_JLONG(0x53152098849316df),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_awt_AttributeValue$method$hashCode$53152098849316df,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_awt_AttributeValue$vtable, java_awt_AttributeValue.hashCode$53152098849316df) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_awt_AttributeValue$linenum_table$hashCode$53152098849316df
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_AttributeValue, hashCode$53152098849316df);

jint _JC_JCNI_ATTR
_jc_java_awt_AttributeValue$method$hashCode$53152098849316df(_jc_env *const env, _jc_java_awt_AttributeValue$object *this)
{
	jint i0;
	struct _jc_java_awt_AttributeValue$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(86);				// 0
	i0 = _JC_PRIM_FIELD(env, r0, java_awt_AttributeValue, value);
	return i0;
}

//
// public java.lang.String toString()
//

static _jc_linenum _jc_java_awt_AttributeValue$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_java_awt_AttributeValue$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_awt_AttributeValue$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_awt_AttributeValue$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_awt_AttributeValue$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_awt_AttributeValue$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_awt_AttributeValue$vtable, java_awt_AttributeValue.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_awt_AttributeValue$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_AttributeValue, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_java_awt_AttributeValue$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_java_awt_AttributeValue$object *this)
{
	jint i0;
	struct _jc_java_awt_AttributeValue$object *r0;
	_jc_object_array *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	_JC_LINE_NUMBER(96);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_awt_AttributeValue, names);
	i0 = _JC_PRIM_FIELD(env, r0, java_awt_AttributeValue, value);
	r2 = _JC_REF_ELEMENT(env, r1, i0, 1, 1);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_awt_AttributeValue$methods[] = {
	&_jc_java_awt_AttributeValue$method_info$_init$8ea9c163215ed755,
	&_jc_java_awt_AttributeValue$method_info$hashCode$53152098849316df,
	&_jc_java_awt_AttributeValue$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_awt_AttributeValue$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_java_awt_AttributeValue$instanceof_hash_bucket_109[] = {
	&_jc_java_awt_AttributeValue$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_awt_AttributeValue$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[101]=	_jc_java_awt_AttributeValue$instanceof_hash_bucket_101,
	[109]=	_jc_java_awt_AttributeValue$instanceof_hash_bucket_109
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_awt_AttributeValue$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_awt_AttributeValue$vtype _jc_java_awt_AttributeValue$type = {
    .type= {
	.name=			"java/awt/AttributeValue",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xad57b0121b5be9ed),
		.source_file=		"AttributeValue.java",
		.instance_size=		sizeof(_jc_java_awt_AttributeValue$refs) + sizeof(_jc_java_awt_AttributeValue$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_awt_AttributeValue$fields) / sizeof(*_jc_java_awt_AttributeValue$fields),
		.fields=		_jc_java_awt_AttributeValue$fields,
		.num_methods=		sizeof(_jc_java_awt_AttributeValue$methods) / sizeof(*_jc_java_awt_AttributeValue$methods),
		.methods=		_jc_java_awt_AttributeValue$methods,
		.instanceof_hash_table=	_jc_java_awt_AttributeValue$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_awt_AttributeValue$class_depends) / sizeof(*_jc_java_awt_AttributeValue$class_depends),
		.class_depends=		_jc_java_awt_AttributeValue$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=			// overridden
		&_jc_java_awt_AttributeValue$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_awt_AttributeValue$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_awt_AttributeValue= {
	    .hashCode$53152098849316df=
		&_jc_java_awt_AttributeValue$method$hashCode$53152098849316df,
	    .toString$7ea43b33b80a3070=
		&_jc_java_awt_AttributeValue$method$toString$7ea43b33b80a3070,
	},
    }
};
